@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 9766 2017-02-21 03:21:39Z David $
+# $Id: __init__.py 9775 2017-02-22 00:04:34Z David $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $ (last)
-# $Date: 2017-02-21 11:21:39 +0800 (Tue, 21 Feb 2017) $
-# $Revision: 9766 $
+# $Date: 2017-02-22 08:04:34 +0800 (Wed, 22 Feb 2017) $
+# $Revision: 9775 $
 
 import os
 import sys
@@ -44,12 +44,17 @@ def attachSettings(settingsDict, enablePaypal=False):
     #=========================================================================
     # Django plugins.
 
+    extraApps = []
+    
+    if 'IUNO_SHOP_EXTRA_APPS' in settingsDict:
+        extraApps = settingsDict['IUNO_SHOP_EXTRA_APPS']
+
     ADDING_INSTALLED_APPS = (
         'django.contrib.sites',
         'django.contrib.flatpages',
         'compressor',
         'widget_tweaks',
-    ) + tuple(get_core_apps())
+    ) + tuple(get_core_apps(extraApps))
     
     ADDING_MIDDLEWARE_CLASSES = (
         'oscar.apps.basket.middleware.BasketMiddleware',
